Crate identity_dbus_broker
identity_
dbus_
broker
0.2.1
All Items
Crate Items
Structs
Traits
Functions
Crate
identity_
dbus_
broker
Structs

LogLevel
Callbacks
Callbacks for getting and setting the log level at runtime. Used by the LogControl1 D-Bus interface to bridge into whatever logging framework the caller uses (e.g. tracing-subscriber reload).
Traits

Device
Broker
Himmelblau
Broker
Session
Broker
Functions

device_
broker_
serve
himmelblau_
broker_
serve
himmelblau_
broker_
serve_
with_
listener
himmelblau_
session_
broker_
serve
register_
device_
broker
session_
broker_
serve